@@ -2,7 +2,7 @@ import time
 from collections import deque
 from typing import Dict, Tuple
 
-import gym
+import gymnasium as gym
 import numpy as np
 import torch
 from torch import Tensor
